XUnitMerge
==========

Utility for merging multiple XUnit xml reports into a single xml report.

The primary purpose of this package is to be able to merge XUnit reports
generated by nosetests (e.g. ``nosetests --with-xunit``). This is especially
useful when nosetests needs to be run multiple times for different parts of
a project and then all reports need to be merged to a single report
(similar to what coverage combine does with multiple coverage reports).

Installing
----------

You can install ``xunitmerge`` using pip::

    $ pip install xunitmerge

Or alternatively you can install the
`development <http://github.com/miki725/xunitmerge/archive/master.tar.gz#egg=xunitmerge-dev>`_
version::

    $ pip install xunitmerge==dev

Using
-----

To use the plugin, use an executable ``xunitmerge`` which should become
available after the installation..
To see it's usage dialog, you can run it with a ``--help`` flag::

    xunitmerge --help

In summary, you can provide any number of paths of reports to be merged and
an output report path::

    xunitmerge report1.xml report2.xml report3.xml merged.xml

You can also use it directly in Python::

    from xunitmerge import merge_xunit

    merge_xunit(files['report1.xml', 'report2.xml'], output='merged.xml)

Running tests
-------------

You can run tests for this package by using nose::

    $ nosetests --with-doctest

Credits
-------

Miroslav Shubernetskiy - `GitHub <https://github.com/miki725>`_

